import logging

from decentnet.consensus.dev_constants import LOG_LEVEL


def setup_logger(debug: bool, logger):
    if not debug:
        logging.disable(logging.DEBUG)
        return
    try:
        from rich.logging import RichHandler
    except ImportError:
        raise ImportError(
            "Rich not installed. Please install decent mesh with pip install decentnet[cli] to be able to see"
            " log and use cli")
    root = logging.getLogger()
    root.setLevel(logging.FATAL)

    logger.setLevel(LOG_LEVEL)
    logging.basicConfig(
        level=LOG_LEVEL if debug else logging.CRITICAL,
        format="%(message)s",
        datefmt="[%X]",
        handlers=[RichHandler()]
    )
    logging.getLogger('sqlalchemy.engine').addHandler(logging.NullHandler())
    aio_log = logging.getLogger('aiosqlite')
    aio_log.setLevel(logging.CRITICAL)
    aio_log.addHandler(logging.NullHandler())
    logging.getLogger('asyncio').setLevel(logging.WARNING)



import rich

from decentnet.modules.cryptography.asymetric import AsymCrypt
from decentnet.modules.key_util.key_manager import KeyManager


async def generate_impl(description: str, private_key_file: str = None, public_key_file: str = None,
                        sign: bool = False, alias: str = None):
    if sign:
        private_key, o_public_key = KeyManager.generate_singing_key_pair()
        public_key = AsymCrypt.verifying_key_to_string(o_public_key)
    else:
        private_key, o_public_key = KeyManager.generate_encryption_key_pair()
        public_key = KeyManager.key_to_base64(o_public_key)

    private_key = KeyManager.key_to_base64(private_key)

    if private_key_file:
        with open(private_key_file, 'w') as f:
            f.write(private_key)
    if public_key_file:
        with open(public_key_file, 'w') as f:
            f.write(public_key)
    await KeyManager.save_to_db(private_key, public_key, description, not sign, alias)
    rich.print("[green]Generated new key and saved to database[/green]")
